package
Version:
v1.4.7
Opens a new window with list of versions in this module.
Published: Jun 12, 2022
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IConfig interface {
CleanCron() string
Address() iAddress
Connections() []string
F2F() iF2F
OnlineChecker() iOnlineChecker
GetService(string) (iBlock, bool)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.